CompareIDs

Struct CompareIDs 

pub struct CompareIDs {
    pub column: u16,
    pub flags: u16,
}
Fields

column: u16flags: u16

Implementations

Source

impl CompareIDs

pub fn to_result(order: Option<Ordering>) -> HRESULT

MAKE_HRESULT macro (dmerror.h)

cmp     dil, 2
movsx   eax, dil
movzx   ecx, ax
mov     eax, -2147483648
cmovne  eax, ecx
ret
Source

impl CompareIDs

pub fn builder() -> CompareIDsBuilder

Create an instance of CompareIDs using the builder syntax

Source

impl CompareIDs

pub const ALL_FIELDS: CompareIDs

Version 5.0. Compare all the information contained in the [ITEMIDLIST] structure, not just the display names. This flag is valid only for folder objects that support the [IShellFolder2] interface. For instance, if the two items are files, the folder should compare their names, sizes, file times, attributes, and any other information in the structures. If this flag is set, column must be zero.

pub const CANONICAL_ONLY: CompareIDs

Version 5.0. When comparing by name, compare the system names but not the display names. When this flag is passed, the two items are compared by whatever criteria the Shell folder determines are most efficient, as long as it implements a consistent sort function. This flag is useful when comparing for equality or when the results of the sort are not displayed to the user. This flag cannot be combined with other flags.