Module inject

Module inject 

Available on crate features hook-dll and hook only.

Structs

ShellItemHook
Represents an injected hook with its syringe, payload, and remote set_hook function.
ShellItemHooks
A collection of injected hooks that can be ejected together.
ShellItemHooksInjectBuilder
Use builder syntax to set the inputs and finish with call().