pub struct ShellItemHooks { /* private fields */ }Available on crate features
hook-dll and hook only.Expand description
A collection of injected hooks that can be ejected together.
Implementations
Sourceimpl ShellItemHooks
impl ShellItemHooks
Sourcepub fn eject(&mut self) -> Result<(), Error>
pub fn eject(&mut self) -> Result<(), Error>
Eject all hooks and return the first error if any.
Sourcepub fn inject<'f1, 'f2>() -> ShellItemHooksInjectBuilder<'f1, 'f2>
pub fn inject<'f1, 'f2>() -> ShellItemHooksInjectBuilder<'f1, 'f2>
Inject the hook DLL into all processes with the given name.
Before ShellItemHooks::eject(), the DLL file will be locked and can’t be deleted.
Returns
Ok(ShellItemHooks)- Successfully injected hooksErr(anyhow::Error)- Error during injection