ItemAttributes

Struct ItemAttributes 

pub struct ItemAttributes(/* private fields */);
These flags represent attributes that can be retrieved on an item (file or folder) or set of items.

They are used with the ShellFolder and ShellItem APIs, most notably ShellFolder::get_attributes_of and ShellItem::get_attributes.

SFGAO (Shobjidl.h)

Implementations

Source

impl ItemAttributes

pub const CanCopy: Self

The specified items can be copied.

pub const CanMove: Self

The specified items can be moved.

Shortcuts can be created for the specified items.

This attribute has the same value as DROPEFFECT_LINK. If a namespace extension returns this attribute, a Create Shortcut entry with a default handler is added to the shortcut menu that is displayed during drag-and-drop operations. The extension can also implement its own handler for the link verb in place of the default. If the extension does so, it is responsible for creating the shortcut.

A Create Shortcut item is also added to the Windows Explorer File menu and to normal shortcut menus. If the item is selected, your application’s IContextMenu::InvokeCommand method is invoked with the lpVerb member of the CMINVOKECOMMANDINFO structure set to link. Your application is responsible for creating the link.

pub const Storage: Self

The specified items can be bound to an IStorage object through IShellFolder::BindToObject. For more information about namespace manipulation capabilities, see IStorage.

pub const CanRename: Self

The specified items can be renamed.

Note that this value is essentially a suggestion; not all namespace clients allow items to be renamed. However, those that do must have this attribute set.

pub const CanDelete: Self

The specified items can be deleted.

pub const HasPropSheet: Self

The specified items have property sheets.

pub const DropTarget: Self

The specified items are drop targets.

pub const CapabilityMask: Self

pub const System: Self

Windows 7 and later. The specified items are system items.

pub const Encrypted: Self

The specified items are encrypted and might require special presentation.

pub const IsSlow: Self

Accessing the item (through IStream or other storage interfaces) is expected to be a slow operation. Applications should avoid accessing items flagged with ItemAttributes::IsSlow.

Note: Opening a stream for an item is generally a slow operation at all times. ItemAttributes::IsSlow indicates that it is expected to be especially slow, for example in the case of slow network connections or offline (FILE_ATTRIBUTE_OFFLINE) files. However, querying ItemAttributes::IsSlow is itself a slow operation. Applications should query ItemAttributes::IsSlow only on a background thread. An alternate method, such as retrieving the PKEY_FileAttributes property and testing for FILE_ATTRIBUTE_OFFLINE, could be used in place of a method call that involves ItemAttributes::IsSlow.

pub const Ghosted: Self

The specified items are shown as dimmed and unavailable to the user.

The specified items are shortcuts.

pub const Share: Self

The specified objects are shared.

pub const ReadOnly: Self

The specified items are read-only.

In the case of folders, this means that new items cannot be created in those folders. This should not be confused with the behavior specified by the FILE_ATTRIBUTE_READONLY flag retrieved by IColumnProvider::GetItemData in a SHCOLUMNDATA structure. FILE_ATTRIBUTE_READONLY has no meaning for Win32 file system folders.

pub const Hidden: Self

The item is hidden and should not be displayed unless the Show hidden files and folders option is enabled in Folder Settings.

pub const DisplayAttrMask: Self

Do not use.

pub const NonEnumerated: Self

The items are nonenumerated items and should be hidden.

They are not returned through an enumerator such as that created by the IShellFolder::EnumObjects method.

pub const NewContent: Self

The items contain new content, as defined by the particular application.

pub const CanMoniker: Self

pub const HasStorage: Self

pub const Stream: Self

Indicates that the item has a stream associated with it.

That stream can be accessed through a call to IShellFolder::BindToObject or IShellItem::BindToHandler with IID_IStream in the riid parameter.

ItemAttributes::CanMoniker, ItemAttributes::HasStorage and ItemAttributes::Stream have the same value.

pub const StorageAncestor: Self

Children of this item are accessible through IStream or IStorage.

Those children are flagged with ItemAttributes::Storage or ItemAttributes::Stream.

pub const Validate: Self

When specified as input, ItemAttributes::Validate instructs the folder to validate that the items contained in a folder or Shell item array exist.

If one or more of those items do not exist, IShellFolder::GetAttributesOf and IShellItemArray::GetAttributes return a failure code. This flag is never returned as an out value. When used with the file system folder, ItemAttributes::Validate instructs the folder to discard cached properties retrieved by clients of IShellFolder2::GetDetailsEx that might have accumulated for the specified items.

pub const Removable: Self

The specified items are on removable media or are themselves removable devices.

pub const Compressed: Self

The specified items are compressed.

pub const Browsable: Self

The specified items can be hosted inside a web browser or Windows Explorer frame.

pub const FileSysAncestor: Self

The specified folders are either file system folders or contain at least one descendant (child, grandchild, or later) that is a file system (ItemAttributes::FileSystem) folder.

pub const Folder: Self

The specified items are folders.

Some items can be flagged with both ItemAttributes::Stream and ItemAttributes::Folder, such as a compressed file with a .zip file name extension. Some applications might include this flag when testing for items that are both files and containers.

pub const FileSystem: Self

The specified folders or files are part of the file system (that is, they are files, directories, or root directories).

The parsed names of the items can be assumed to be valid Win32 file system paths. These paths can be either UNC or drive-letter based.

pub const StorageCapMask: Self

pub const HasSubFolder: Self

The specified folders have subfolders.

The ItemAttributes::HasSubFolder attribute is only advisory and might be returned by Shell folder implementations even if they do not contain subfolders. Note, however, that the converse—failing to return ItemAttributes::HasSubFolder—definitively states that the folder objects do not have subfolders. Returning ItemAttributes::HasSubFolder is recommended whenever a significant amount of time is required to determine whether any subfolders exist. For example, the Shell always returns ItemAttributes::HasSubFolder when a folder is located on a network drive.

Remark

ItemAttributes::HasSubFolder may access local drives, which can be slow.

pub const ContentMask: Self

This flag is a mask for content attributes, at present only ItemAttributes::HasSubFolder.

Callers normally do not use this value.

pub const PkeySfgaoMask: Self

Mask used by the PKEY_SFGAOFlags property to determine attributes that are considered to cause slow calculations or lack context: ItemAttributes::IsSlow, ItemAttributes::ReadOnly, ItemAttributes::HasSubFolder, and ItemAttributes::Validate.

Callers normally do not use this value.

Source

impl ItemAttributes

pub const fn empty() -> Self

Get a flags value with all bits unset.

pub const fn all() -> Self

Get a flags value with all known bits set.

pub const fn bits(&self) -> u32

Get the underlying bits value.

The returned value is exactly the bits set in this flags value.

pub const fn from_bits(bits: u32) -> Option<Self>

Convert from a bits value.

This method will return None if any unknown bits are set.

pub const fn from_bits_truncate(bits: u32) -> Self

Convert from a bits value, unsetting any unknown bits.

pub const fn from_bits_retain(bits: u32) -> Self

Convert from a bits value exactly.

pub fn from_name(name: &str) -> Option<Self>

Get a flags value with the bits of a flag with the given name set.

This method will return None if name is empty or doesn’t correspond to any named flag.

pub const fn is_empty(&self) -> bool

Whether all bits in this flags value are unset.

pub const fn is_all(&self) -> bool

Whether all known bits in this flags value are set.

pub const fn intersects(&self, other: Self) -> bool

Whether any set bits in a source flags value are also set in a target flags value.

pub const fn contains(&self, other: Self) -> bool

Whether all set bits in a source flags value are also set in a target flags value.

pub fn insert(&mut self, other: Self)

The bitwise or (|) of the bits in two flags values.

pub fn remove(&mut self, other: Self)

The intersection of a source flags value with the complement of a target flags value (&!).

This method is not equivalent to self & !other when other has unknown bits set. remove won’t truncate other, but the ! operator will.

pub fn toggle(&mut self, other: Self)

The bitwise exclusive-or (^) of the bits in two flags values.

pub fn set(&mut self, other: Self, value: bool)

Call insert when value is true or remove when value is false.

pub const fn intersection(self, other: Self) -> Self

The bitwise and (&) of the bits in two flags values.

pub const fn union(self, other: Self) -> Self

The bitwise or (|) of the bits in two flags values.

pub const fn difference(self, other: Self) -> Self

The intersection of a source flags value with the complement of a target flags value (&!).

This method is not equivalent to self & !other when other has unknown bits set. difference won’t truncate other, but the ! operator will.

pub const fn symmetric_difference(self, other: Self) -> Self

The bitwise exclusive-or (^) of the bits in two flags values.

pub const fn complement(self) -> Self

The bitwise negation (!) of the bits in a flags value, truncating the result.

Source

impl ItemAttributes

pub const fn iter(&self) -> Iter<ItemAttributes>

Yield a set of contained flags values.

Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.

pub const fn iter_names(&self) -> IterNames<ItemAttributes>

Yield a set of contained named flags values.

This method is like iter, except only yields bits in contained named flags. Any unknown bits, or bits not corresponding to a contained flag will not be yielded.