#[repr(i32)]pub enum ShellItemDisplayName {
NormalDisplay = 0,
ParentRelativeParsing = -2_147_385_343,
DesktopAbsoluteParsing = -2_147_319_808,
ParentRelativeEditing = -2_147_282_943,
DesktopAbsoluteEditing = -2_147_172_352,
FileSystemPath = -2_147_123_200,
Url = -2_147_057_664,
ParentRelativeForAddressBar = -2_146_975_743,
ParentRelative = -2_146_959_359,
ParentRelativeForUI = -2_146_877_439,
}Expand description
Requests the form of an item’s display name to retrieve through IShellItem::GetDisplayName and [SHGetNameFromIDList].
Variants
NormalDisplay = 0
0x00000000. Returns the display name relative to the parent folder.
In UI this name is generally ideal for display to the user.
ParentRelativeParsing = -2_147_385_343
0x80018001. Returns the parsing name relative to the parent folder.
This name is not suitable for use in UI.
DesktopAbsoluteParsing = -2_147_319_808
0x80028000. Returns the parsing name relative to the desktop.
This name is not suitable for use in UI.
ParentRelativeEditing = -2_147_282_943
0x80031001. Returns the editing name relative to the parent folder.
In UI this name is suitable for display to the user.
DesktopAbsoluteEditing = -2_147_172_352
0x8004c000. Returns the editing name relative to the desktop.
In UI this name is suitable for display to the user.
FileSystemPath = -2_147_123_200
0x80058000. Returns the item’s file system path, if it has one.
Only items that report [SFGAO_FILESYSTEM] have a file system path. When an item does not have a file system path, a call to IShellItem::GetDisplayName on that item will fail.
In UI this name is suitable for display to the user in some cases, but note that it might not be specified for all items.
e.g. C:\Users\Ib
Url = -2_147_057_664
0x80068000. Returns the item’s URL, if it has one.
Some items do not have a URL, and in those cases a call to IShellItem::GetDisplayName will fail.
This name is suitable for display to the user in some cases, but note that it might not be specified for all items.
ParentRelativeForAddressBar = -2_146_975_743
0x8007c001. Returns the path relative to the parent folder in a friendly format as displayed in an address bar.
This name is suitable for display to the user.
ParentRelative = -2_146_959_359
0x80080001. Returns the path relative to the parent folder.
ParentRelativeForUI = -2_146_877_439
0x80094001. Introduced in Windows 8. Returns the path relative to the parent folder for UI purposes.